.. toctree::
   :maxdepth: 2
   :hidden:

   protocol
   api-docs

.. contents::

.. include:: ../README.md
   :parser: myst_parser.sphinx_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
